@@ -454,29 +454,17 @@ class VDBService(object):
             self.logger.error("get_vector_store called with no collection_name.")
             raise ValueError("collection_name must be provided.")
 
-        check_existence = True
-        # Check for a cached instance and validate its connection before returning.
+        # Check for a cached instance. If found, return it immediately.
         if collection_name in self._instances:
-            instance = self._instances[collection_name]
-            is_connected, collection_exists = self._is_good_connection(instance, collection_name)
-            
-            if is_connected and collection_exists:
-                self.logger.info(f"Returning existing vector store instance for collection: {collection_name}")
-                return instance
-            
-            self.logger.warning(f"Cached instance for '{collection_name}' is invalid. Removing it from cache.")
-            del self._instances[collection_name]
-            
-            if is_connected and not collection_exists:
-                # We know the collection doesn't exist, so no need to check again.
-                check_existence = False
+            self.logger.info(f"Returning existing vector store instance for collection: {collection_name}")
+            return self._instances[collection_name]
 
         self.logger.info(f"Creating new vector store instance for collection: {collection_name}")
         if embeddings is None:
             embeddings = self.get_embeddings()
 
         # Ensure the collection exists before proceeding.
-        self._ensure_collection_exists(collection_name, embeddings, check_existence=check_existence)
+        self._ensure_collection_exists(collection_name, embeddings, check_existence=True)
 
         # 1. Validate the embedding function before proceeding.
         try:
@@ -545,26 +533,16 @@ class VDBService(object):
             self.logger.error("aget_vector_store called with no collection_name.")
             raise ValueError("collection_name must be provided.")
 
-        check_existence = True
+        # Check for a cached instance. If found, return it immediately.
         if collection_name in self._async_instances:
-            instance = self._async_instances[collection_name]
-            is_connected, collection_exists = await self._ais_good_connection(instance, collection_name)
-            
-            if is_connected and collection_exists:
-                self.logger.info(f"Returning existing async vector store instance for collection: {collection_name}")
-                return instance
-            
-            self.logger.warning(f"Cached async instance for '{collection_name}' is invalid. Removing it from cache.")
-            del self._async_instances[collection_name]
-            
-            if is_connected and not collection_exists:
-                check_existence = False
+            self.logger.info(f"Returning existing async vector store instance for collection: {collection_name}")
+            return self._async_instances[collection_name]
 
         self.logger.info(f"Creating new async vector store instance for collection: {collection_name}")
         if embeddings is None:
             embeddings = self.get_embeddings()
 
-        # await self._aensure_collection_exists(collection_name, embeddings, check_existence=check_existence)
+        await self._aensure_collection_exists(collection_name, embeddings, check_existence=True)
 
         try:
             self.logger.info(f"Testing embedding function for collection '{collection_name}'...")
